@@ -4,7 +4,6 @@ package announce
 import (
 	"fmt"
 
-	"github.com/caarlos0/log"
 	"github.com/goreleaser/goreleaser/internal/middleware/errhandler"
 	"github.com/goreleaser/goreleaser/internal/middleware/logging"
 	"github.com/goreleaser/goreleaser/internal/middleware/skip"
@@ -12,6 +11,7 @@ import (
 	"github.com/goreleaser/goreleaser/internal/pipe/linkedin"
 	"github.com/goreleaser/goreleaser/internal/pipe/mastodon"
 	"github.com/goreleaser/goreleaser/internal/pipe/mattermost"
+	"github.com/goreleaser/goreleaser/internal/pipe/opencollective"
 	"github.com/goreleaser/goreleaser/internal/pipe/reddit"
 	"github.com/goreleaser/goreleaser/internal/pipe/slack"
 	"github.com/goreleaser/goreleaser/internal/pipe/smtp"
@@ -36,6 +36,7 @@ var announcers = []Announcer{
 	linkedin.Pipe{},
 	mastodon.Pipe{},
 	mattermost.Pipe{},
+	opencollective.Pipe{},
 	reddit.Pipe{},
 	slack.Pipe{},
 	smtp.Pipe{},
@@ -50,20 +51,11 @@ type Pipe struct{}
 
 func (Pipe) String() string { return "announcing" }
 
-func (Pipe) Skip(ctx *context.Context) bool {
+func (Pipe) Skip(ctx *context.Context) (bool, error) {
 	if ctx.SkipAnnounce {
-		return true
+		return true, nil
 	}
-	if ctx.Config.Announce.Skip == "" {
-		return false
-	}
-	skip, err := tmpl.New(ctx).Apply(ctx.Config.Announce.Skip)
-	if err != nil {
-		log.Error("invalid announce.skip template, will skip the announcing step")
-		return true
-	}
-	log.Debugf("announce.skip evaluated from %q to %q", ctx.Config.Announce.Skip, skip)
-	return skip == "true"
+	return tmpl.New(ctx).Bool(ctx.Config.Announce.Skip)
 }
 
 // Run the pipe.
