@@ -3,8 +3,8 @@ package mastodon
 import (
 	"testing"
 
+	"github.com/goreleaser/goreleaser/internal/testctx"
 	"github.com/goreleaser/goreleaser/pkg/config"
-	"github.com/goreleaser/goreleaser/pkg/context"
 	"github.com/stretchr/testify/require"
 )
 
@@ -13,13 +13,13 @@ func TestStringer(t *testing.T) {
 }
 
 func TestDefault(t *testing.T) {
-	ctx := context.New(config.Project{})
+	ctx := testctx.New()
 	require.NoError(t, Pipe{}.Default(ctx))
 	require.Equal(t, ctx.Config.Announce.Mastodon.MessageTemplate, defaultMessageTemplate)
 }
 
 func TestAnnounceInvalidTemplate(t *testing.T) {
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		Announce: config.Announce{
 			Mastodon: config.Mastodon{
 				MessageTemplate: "{{ .Foo }",
@@ -30,7 +30,7 @@ func TestAnnounceInvalidTemplate(t *testing.T) {
 }
 
 func TestAnnounceMissingEnv(t *testing.T) {
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		Announce: config.Announce{
 			Mastodon: config.Mastodon{},
 		},
@@ -41,11 +41,11 @@ func TestAnnounceMissingEnv(t *testing.T) {
 
 func TestSkip(t *testing.T) {
 	t.Run("skip", func(t *testing.T) {
-		require.True(t, Pipe{}.Skip(context.New(config.Project{})))
+		require.True(t, Pipe{}.Skip(testctx.New()))
 	})
 
 	t.Run("skip empty server", func(t *testing.T) {
-		require.True(t, Pipe{}.Skip(context.New(config.Project{
+		require.True(t, Pipe{}.Skip(testctx.NewWithCfg(config.Project{
 			Announce: config.Announce{
 				Mastodon: config.Mastodon{
 					Enabled: true,
@@ -56,7 +56,7 @@ func TestSkip(t *testing.T) {
 	})
 
 	t.Run("dont skip", func(t *testing.T) {
-		require.False(t, Pipe{}.Skip(context.New(config.Project{
+		require.False(t, Pipe{}.Skip(testctx.NewWithCfg(config.Project{
 			Announce: config.Announce{
 				Mastodon: config.Mastodon{
 					Enabled: true,
