@@ -15,8 +15,8 @@ import (
 // Pipe implementation.
 type Pipe struct{}
 
-func (Pipe) String() string                 { return "storing release metadata" }
-func (Pipe) Skip(ctx *context.Context) bool { return false }
+func (Pipe) String() string               { return "storing release metadata" }
+func (Pipe) Skip(_ *context.Context) bool { return false }
 
 // Run the pipe.
 func (Pipe) Run(ctx *context.Context) error {
@@ -44,6 +44,7 @@ func writeMetadata(ctx *context.Context) error {
 func writeArtifacts(ctx *context.Context) error {
 	_ = ctx.Artifacts.Visit(func(a *artifact.Artifact) error {
 		a.TypeS = a.Type.String()
+		a.Path = filepath.ToSlash(filepath.Clean(a.Path))
 		return nil
 	})
 	return writeJSON(ctx, ctx.Artifacts.List(), "artifacts.json")
