@@ -8,8 +8,8 @@ import (
 	"os"
 	"path/filepath"
 
-	"github.com/apex/log"
 	"github.com/caarlos0/go-shellwords"
+	"github.com/caarlos0/log"
 	"github.com/goreleaser/goreleaser/internal/artifact"
 	"github.com/goreleaser/goreleaser/internal/ids"
 	"github.com/goreleaser/goreleaser/internal/pipe"
@@ -148,7 +148,7 @@ func makeUniversalBinary(ctx *context.Context, opts *build.Options, unibin confi
 
 	binaries := ctx.Artifacts.Filter(filterFor(unibin)).List()
 	if len(binaries) == 0 {
-		return pipe.Skip(fmt.Sprintf("no darwin binaries found with id %q", unibin.ID))
+		return pipe.Skipf("no darwin binaries found with id %q", unibin.ID)
 	}
 
 	log.WithField("id", unibin.ID).
