@@ -10,9 +10,9 @@ import (
 	"time"
 
 	"github.com/goreleaser/goreleaser/internal/artifact"
+	"github.com/goreleaser/goreleaser/internal/testctx"
 	"github.com/goreleaser/goreleaser/internal/testlib"
 	"github.com/goreleaser/goreleaser/pkg/config"
-	"github.com/goreleaser/goreleaser/pkg/context"
 	"github.com/stretchr/testify/require"
 )
 
@@ -22,14 +22,12 @@ func TestDescription(t *testing.T) {
 
 func TestDefault(t *testing.T) {
 	t.Run("empty", func(t *testing.T) {
-		ctx := &context.Context{
-			Config: config.Project{
-				ProjectName: "proj",
-				UniversalBinaries: []config.UniversalBinary{
-					{},
-				},
+		ctx := testctx.NewWithCfg(config.Project{
+			ProjectName: "proj",
+			UniversalBinaries: []config.UniversalBinary{
+				{},
 			},
-		}
+		})
 		require.NoError(t, Pipe{}.Default(ctx))
 		require.Equal(t, config.UniversalBinary{
 			ID:           "proj",
@@ -39,14 +37,12 @@ func TestDefault(t *testing.T) {
 	})
 
 	t.Run("given ids", func(t *testing.T) {
-		ctx := &context.Context{
-			Config: config.Project{
-				ProjectName: "proj",
-				UniversalBinaries: []config.UniversalBinary{
-					{IDs: []string{"foo"}},
-				},
+		ctx := testctx.NewWithCfg(config.Project{
+			ProjectName: "proj",
+			UniversalBinaries: []config.UniversalBinary{
+				{IDs: []string{"foo"}},
 			},
-		}
+		})
 		require.NoError(t, Pipe{}.Default(ctx))
 		require.Equal(t, config.UniversalBinary{
 			ID:           "proj",
@@ -56,14 +52,12 @@ func TestDefault(t *testing.T) {
 	})
 
 	t.Run("given id", func(t *testing.T) {
-		ctx := &context.Context{
-			Config: config.Project{
-				ProjectName: "proj",
-				UniversalBinaries: []config.UniversalBinary{
-					{ID: "foo"},
-				},
+		ctx := testctx.NewWithCfg(config.Project{
+			ProjectName: "proj",
+			UniversalBinaries: []config.UniversalBinary{
+				{ID: "foo"},
 			},
-		}
+		})
 		require.NoError(t, Pipe{}.Default(ctx))
 		require.Equal(t, config.UniversalBinary{
 			ID:           "foo",
@@ -73,14 +67,12 @@ func TestDefault(t *testing.T) {
 	})
 
 	t.Run("given name", func(t *testing.T) {
-		ctx := &context.Context{
-			Config: config.Project{
-				ProjectName: "proj",
-				UniversalBinaries: []config.UniversalBinary{
-					{NameTemplate: "foo"},
-				},
+		ctx := testctx.NewWithCfg(config.Project{
+			ProjectName: "proj",
+			UniversalBinaries: []config.UniversalBinary{
+				{NameTemplate: "foo"},
 			},
-		}
+		})
 		require.NoError(t, Pipe{}.Default(ctx))
 		require.Equal(t, config.UniversalBinary{
 			ID:           "proj",
@@ -90,26 +82,24 @@ func TestDefault(t *testing.T) {
 	})
 
 	t.Run("duplicated ids", func(t *testing.T) {
-		ctx := &context.Context{
-			Config: config.Project{
-				ProjectName: "proj",
-				UniversalBinaries: []config.UniversalBinary{
-					{ID: "foo"},
-					{ID: "foo"},
-				},
+		ctx := testctx.NewWithCfg(config.Project{
+			ProjectName: "proj",
+			UniversalBinaries: []config.UniversalBinary{
+				{ID: "foo"},
+				{ID: "foo"},
 			},
-		}
+		})
 		require.EqualError(t, Pipe{}.Default(ctx), `found 2 universal_binaries with the ID 'foo', please fix your config`)
 	})
 }
 
 func TestSkip(t *testing.T) {
 	t.Run("skip", func(t *testing.T) {
-		require.True(t, Pipe{}.Skip(context.New(config.Project{})))
+		require.True(t, Pipe{}.Skip(testctx.New()))
 	})
 
 	t.Run("dont skip", func(t *testing.T) {
-		ctx := context.New(config.Project{
+		ctx := testctx.NewWithCfg(config.Project{
 			UniversalBinaries: []config.UniversalBinary{{}},
 		})
 		require.False(t, Pipe{}.Skip(ctx))
@@ -138,9 +128,9 @@ func TestRun(t *testing.T) {
 			},
 		},
 	}
-	ctx1 := context.New(cfg)
+	ctx1 := testctx.NewWithCfg(cfg)
 
-	ctx2 := context.New(config.Project{
+	ctx2 := testctx.NewWithCfg(config.Project{
 		Dist: dist,
 		UniversalBinaries: []config.UniversalBinary{
 			{
@@ -151,7 +141,7 @@ func TestRun(t *testing.T) {
 		},
 	})
 
-	ctx3 := context.New(config.Project{
+	ctx3 := testctx.NewWithCfg(config.Project{
 		Dist: dist,
 		UniversalBinaries: []config.UniversalBinary{
 			{
@@ -162,7 +152,7 @@ func TestRun(t *testing.T) {
 		},
 	})
 
-	ctx4 := context.New(config.Project{
+	ctx4 := testctx.NewWithCfg(config.Project{
 		Dist: dist,
 		UniversalBinaries: []config.UniversalBinary{
 			{
@@ -173,7 +163,7 @@ func TestRun(t *testing.T) {
 		},
 	})
 
-	ctx5 := context.New(config.Project{
+	ctx5 := testctx.NewWithCfg(config.Project{
 		Dist: dist,
 		UniversalBinaries: []config.UniversalBinary{
 			{
@@ -193,7 +183,7 @@ func TestRun(t *testing.T) {
 		},
 	})
 
-	ctx6 := context.New(config.Project{
+	ctx6 := testctx.NewWithCfg(config.Project{
 		Dist: dist,
 		UniversalBinaries: []config.UniversalBinary{
 			{
@@ -268,7 +258,7 @@ func TestRun(t *testing.T) {
 	})
 
 	t.Run("bad template", func(t *testing.T) {
-		testlib.RequireTemplateError(t, Pipe{}.Run(context.New(config.Project{
+		testlib.RequireTemplateError(t, Pipe{}.Run(testctx.NewWithCfg(config.Project{
 			UniversalBinaries: []config.UniversalBinary{
 				{
 					NameTemplate: "{{.Name}",
